pub struct WitLanguage {}Trait Implementations
Sourceimpl Default for WitLanguage
impl Default for WitLanguage
Sourcefn default() -> WitLanguage
fn default() -> WitLanguage
Returns the “default value” for a type. Read more
Sourceimpl Language for WitLanguage
impl Language for WitLanguage
Sourceconst CATEGORY: LanguageCategory = LanguageCategory::Dsl
const CATEGORY: LanguageCategory = LanguageCategory::Dsl
The category of the language.
Sourcetype TokenType = WitSyntaxKind
type TokenType = WitSyntaxKind
The token type used to represent different token and node types in the language. Read more
Sourcetype ElementType = WitSyntaxKind
type ElementType = WitSyntaxKind
The element type used to represent composite structures in the parsed tree. Read more
Sourceimpl<'config> Lexer<WitLanguage> for WitLexer<'config>
impl<'config> Lexer<WitLanguage> for WitLexer<'config>
Sourcefn lex<'a, S: Source + ?Sized>(
&self,
source: &S,
_edits: &[TextEdit],
cache: &'a mut impl LexerCache<WitLanguage>,
) -> LexOutput<WitLanguage>
fn lex<'a, S: Source + ?Sized>( &self, source: &S, _edits: &[TextEdit], cache: &'a mut impl LexerCache<WitLanguage>, ) -> LexOutput<WitLanguage>
Tokenizes the given source text into a sequence of tokens. Read more
Sourceimpl<'config> Parser<WitLanguage> for WitParser<'config>
impl<'config> Parser<WitLanguage> for WitParser<'config>
Sourcefn parse<'a, S: Source + ?Sized>(
&self,
text: &'a S,
edits: &[TextEdit],
cache: &'a mut impl ParseCache<WitLanguage>,
) -> ParseOutput<'a, WitLanguage>
fn parse<'a, S: Source + ?Sized>( &self, text: &'a S, edits: &[TextEdit], cache: &'a mut impl ParseCache<WitLanguage>, ) -> ParseOutput<'a, WitLanguage>
The core parsing entry point. Read more