pub struct WitLanguage {}Trait Implementations
Sourceimpl Language for WitLanguage
impl Language for WitLanguage
Sourcetype SyntaxKind = WitSyntaxKind
type SyntaxKind = WitSyntaxKind
The kind kind type used to represent different kind and node types in the language. Read more
Sourceimpl<'config> Lexer<WitLanguage> for WitLexer<'config>
impl<'config> Lexer<WitLanguage> for WitLexer<'config>
Sourcefn lex_incremental(
&self,
source: impl Source,
changed: usize,
cache: IncrementalCache<'_, WitLanguage>,
) -> LexOutput<WitLanguage>
fn lex_incremental( &self, source: impl Source, changed: usize, cache: IncrementalCache<'_, WitLanguage>, ) -> LexOutput<WitLanguage>
Tokenizes source text using an existing cache for incremental parsing. Read more
Sourcefn lex(
&self,
source: impl Source,
) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
fn lex( &self, source: impl Source, ) -> OakDiagnostics<Vec<Token<<L as Language>::SyntaxKind>>>
Tokenizes the given source text into a sequence of tokens. Read more